@@ -48,8 +48,7 @@ REACTOR_TYPES = {
     'drag-nuclear-reactor': {'bonder-count': 4, 'has-fuser': True, 'has-splitter': True},
     'drag-quantum-reactor': {'bonder-count': 4, 'has-sensor': True, 'has-teleporter': True,
                              'quantum-walls-y': {5: [0, 1, 2, 3, 4, 5, 6, 7]}},
-    'drag-sandbox-reactor': {'bonder-count': 8, 'has-sensor': True, 'has-fuser': True, 'has-splitter': True,
-                             'has-teleporter':True}}
+    'drag-sandbox-reactor': {'bonder-count': 8, 'has-sensor': True, 'has-fuser': True, 'has-splitter': True}}
 
 
 class Pipe(list):
@@ -117,7 +116,7 @@ class Component:
     '''Informal Interface class defining methods overworld objects will implement one or more of.'''
     __slots__ = 'type', 'posn', 'dimensions', 'in_pipes', 'out_pipes'
 
-    def __new__(cls, *args, component_dict=None, _type=None, **kwargs):
+    def __new__(cls, component_dict=None, _type=None, **kwargs):
         '''Return a new object of the appropriate subclass based on the component type.'''
         # If this is being called from a child class, behave like a normal __new__ implementation (to avoid recursion)
         if cls != Component:
@@ -466,7 +465,7 @@ class DisabledOutput(Component):
     def in_pipe(self):
         return self.in_pipes[0]
 
-    def __init__(self, _type, posn):
+    def __init__(self, *, _type, posn):
         super().__init__(_type=_type, posn=posn, num_in_pipes=1)
 
     def do_instant_actions(self, _):
